% NTQR documentation master file, created by
% sphinx-quickstart on Fri Jan 19 05:39:11 2024.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

```{include} ../../README.md
:relative-images:
```

```{toctree}
:caption: 'Contents:'
:maxdepth: 2


conceptual
notebooks/Tutorial
notebooks/LogicOfUnsupervisedEvaluationTutorial
research/GradingLLMs
research/MathematicsOfAlgebraicEvaluation
research/TheScienceOfAlgebraicEvaluation
ntqr
```

